import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:syncrow_web/pages/space_management_v2/main_module/widgets/community_structure_header_action_buttons.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/presentation/communities_tree_selection_bloc/communities_tree_selection_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/create_community/presentation/create_community_dialog.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/helpers/space_details_dialog_helper.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class CommunityStructureHeader extends StatelessWidget {
  const CommunityStructureHeader({super.key});

  @override
  Widget build(BuildContext context) {
    final theme = Theme.of(context);
    final screenWidth = MediaQuery.of(context).size.width;
    return Container(
      padding: const EdgeInsets.symmetric(horizontal: 16.0, vertical: 16.0),
      decoration: BoxDecoration(
        color: ColorsManager.whiteColors,
        boxShadow: [
          BoxShadow(
            color: ColorsManager.shadowBlackColor,
            blurRadius: 8,
            offset: const Offset(0, 4),
          ),
        ],
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: _buildCommunityInfo(context, theme, screenWidth),
              ),
              const SizedBox(width: 16),
            ],
          ),
        ],
      ),
    );
  }

  void _showCreateCommunityDialog(BuildContext context) {
    showDialog<void>(
      context: context,
      builder: (context) => CreateCommunityDialog(
        title: const Text('Edit Community'),
        onCreateCommunity: (community) {
          // TODO(FarisArmoush): Implement
        },
      ),
    );
  }

  Widget _buildCommunityInfo(
      BuildContext context, ThemeData theme, double screenWidth) {
    final selectedCommunity =
        context.watch<CommunitiesTreeSelectionBloc>().state.selectedCommunity;
    final selectedSpace =
        context.watch<CommunitiesTreeSelectionBloc>().state.selectedSpace;
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          'Community Structure',
          style: theme.textTheme.headlineLarge
              ?.copyWith(color: ColorsManager.blackColor),
        ),
        if (selectedCommunity != null)
          Row(
            children: [
              Expanded(
                child: Row(
                  children: [
                    Flexible(
                      child: SelectableText(
                        selectedCommunity.name,
                        style: theme.textTheme.bodyLarge
                            ?.copyWith(color: ColorsManager.blackColor),
                        maxLines: 1,
                      ),
                    ),
                    const SizedBox(width: 2),
                    GestureDetector(
                      onTap: () => _showCreateCommunityDialog(context),
                      child: SvgPicture.asset(
                        Assets.iconEdit,
                        width: 16,
                        height: 16,
                      ),
                    ),
                  ],
                ),
              ),
              const SizedBox(width: 8),
              CommunityStructureHeaderActionButtons(
                onDelete: (space) {},
                onDuplicate: (space) {},
                onEdit: (space) {
                  SpaceDetailsDialogHelper.showEdit(
                    context,
                    spaceModel: selectedSpace!,
                  );
                },
                selectedSpace: selectedSpace,
              ),
            ],
          ),
      ],
    );
  }
}
