import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class ButtonContentWidget extends StatelessWidget {
  final String label;
  final String? svgAssets;
  final bool disabled;

  const ButtonContentWidget({
    required this.label,
    this.svgAssets,
    this.disabled = false,
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    final screenWidth = MediaQuery.of(context).size.width;

    return Opacity(
      opacity: disabled ? 0.5 : 1.0,
      child: Container(
        width: screenWidth * 0.25,
        decoration: BoxDecoration(
          color: ColorsManager.textFieldGreyColor,
          border: Border.all(
            color: ColorsManager.neutralGray,
            width: 3.0,
          ),
          borderRadius: BorderRadius.circular(20),
        ),
        padding: const EdgeInsets.symmetric(vertical: 10.0, horizontal: 16.0),
        child: Row(
          children: [
            if (svgAssets != null)
              Padding(
                padding: const EdgeInsets.only(left: 6.0),
                child: SvgPicture.asset(
                  svgAssets!,
                  width: screenWidth * 0.015,
                  height: screenWidth * 0.015,
                ),
              ),
            const SizedBox(width: 10),
            Expanded(
              child: Text(
                label,
                style: const TextStyle(
                  color: ColorsManager.blackColor,
                  fontSize: 16,
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
