import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_icon_selection_dialog.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_space/presentation/bloc/space_details_model_bloc/space_details_model_bloc.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SpaceIconPicker extends StatelessWidget {
  const SpaceIconPicker({
    required this.iconPath,
    super.key,
  });

  final String iconPath;

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        const SizedBox(height: 50),
        Stack(
          alignment: Alignment.center,
          children: [
            Container(
              width: context.screenWidth * 0.1,
              height: context.screenWidth * 0.1,
              decoration: const BoxDecoration(
                color: ColorsManager.boxColor,
                shape: BoxShape.circle,
              ),
            ),
            SvgPicture.asset(
              iconPath,
              width: context.screenWidth * 0.04,
              height: context.screenWidth * 0.04,
            ),
            Positioned(
              top: 20,
              right: 20,
              child: InkWell(
                onTap: () {
                  showDialog<String?>(
                    context: context,
                    builder: (context) => SpaceIconSelectionDialog(
                      selectedIcon: iconPath,
                    ),
                  ).then((value) {
                    if (value != null) {
                      if (context.mounted) {
                        context.read<SpaceDetailsModelBloc>().add(
                              UpdateSpaceDetailsIcon(value),
                            );
                      }
                    }
                  });
                },
                child: Container(
                  width: 24,
                  height: 24,
                  decoration: const BoxDecoration(
                    color: Colors.white,
                    shape: BoxShape.circle,
                  ),
                  child: SvgPicture.asset(
                    Assets.iconEdit,
                    width: 16,
                    height: 16,
                  ),
                ),
              ),
            ),
          ],
        ),
      ],
    );
  }
}
