import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_space/presentation/bloc/space_details_model_bloc/space_details_model_bloc.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class SpaceNameTextField extends StatefulWidget {
  const SpaceNameTextField({
    required this.initialValue,
    required this.isNameFieldExist,
    super.key,
  });

  final String? initialValue;
  final bool Function(String value) isNameFieldExist;

  @override
  State<SpaceNameTextField> createState() => _SpaceNameTextFieldState();
}

class _SpaceNameTextFieldState extends State<SpaceNameTextField> {
  late final TextEditingController _controller;

  @override
  void initState() {
    _controller = TextEditingController(text: widget.initialValue);
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  final _formKey = GlobalKey<FormState>();

  String? _validateName(String? value) {
    if (value == null || value.isEmpty) {
      return '*Space name should not be empty.';
    }
    if (widget.isNameFieldExist(value)) {
      return '*Name already exists';
    }
    return null;
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      autovalidateMode: AutovalidateMode.onUserInteraction,
      child: TextFormField(
        controller: _controller,
        onChanged: (value) => context.read<SpaceDetailsModelBloc>().add(
              UpdateSpaceDetailsName(value),
            ),
        validator: _validateName,
        style: Theme.of(context).textTheme.bodyMedium,
        decoration: InputDecoration(
          hintText: 'Please enter the name',
          hintStyle: context.textTheme.bodyMedium!.copyWith(
            color: ColorsManager.lightGrayColor,
          ),
          filled: true,
          fillColor: ColorsManager.boxColor,
          enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(10),
            borderSide: const BorderSide(width: 1.5),
          ),
          focusedBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(10),
            borderSide: const BorderSide(
              color: ColorsManager.boxColor,
            ),
          ),
          errorStyle: context.textTheme.bodySmall?.copyWith(
            color: ColorsManager.red,
          ),
        ),
      ),
    );
  }
}
