import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/domain/models/space_details_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/space_details_action_buttons.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/space_details/presentation/widgets/sub_spaces_input.dart';
import 'package:uuid/uuid.dart';

class SpaceSubSpacesDialog extends StatefulWidget {
  const SpaceSubSpacesDialog({
    required this.subspaces,
    required this.onSave,
    super.key,
  });

  final List<Subspace> subspaces;
  final void Function(List<Subspace> subspaces) onSave;

  @override
  State<SpaceSubSpacesDialog> createState() => _SpaceSubSpacesDialogState();
}

class _SpaceSubSpacesDialogState extends State<SpaceSubSpacesDialog> {
  late List<Subspace> _subspaces;

  bool get _hasDuplicateNames =>
      _subspaces.map((subspace) => subspace.name.toLowerCase()).toSet().length !=
      _subspaces.length;

  @override
  void initState() {
    super.initState();
    _subspaces = List.from(widget.subspaces);
  }

  void _handleSubspaceAdded(String name) {
    setState(() {
      _subspaces = [
        ..._subspaces,
        Subspace(
          name: name,
          uuid: const Uuid().v4(),
          productAllocations: const [],
        ),
      ];
    });
  }

  void _handleSubspaceDeleted(String uuid) => setState(
        () => _subspaces = _subspaces.where((s) => s.uuid != uuid).toList(),
      );

  void _handleSave() {
    widget.onSave(_subspaces);
    Navigator.of(context).pop();
  }

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      title: const Text('Create Sub Spaces'),
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          SubSpacesInput(
            subSpaces: _subspaces,
            onSubspaceAdded: _handleSubspaceAdded,
            onSubspaceDeleted: _handleSubspaceDeleted,
          ),
          AnimatedSwitcher(
            duration: const Duration(milliseconds: 100),
            child: Visibility(
              key: ValueKey(_hasDuplicateNames),
              visible: _hasDuplicateNames,
              child: const Text(
                'Error: Duplicate subspace names are not allowed.',
                style: TextStyle(color: Colors.red),
              ),
            ),
          ),
        ],
      ),
      actions: [
        SpaceDetailsActionButtons(
          onSave: _hasDuplicateNames ? null : _handleSave,
          onCancel: Navigator.of(context).pop,
        )
      ],
    );
  }
}
